@@ -1,8 +1,7 @@
 package Storage::SQLite;
 
-use strict;
-use warnings;
 use Moo::Role;
+with qw(Storage::Common);
 
 sub connect_info { 'dbi:SQLite::memory:', undef, undef, { RaiseError => 1 } }
 
